import { BigNumber, ethers, ContractReceipt } from "ethers";
import { ChainName, Network } from "../../utils";
import { SignedVaa } from "../../vaa";
import { RelayerPayloadId, DeliveryInstruction, DeliveryOverrideArgs, VaaKey } from "../structs";
import { DeliveryTargetInfo } from "./helpers";
export declare type CCTPTransferParsed = {
    amount: bigint;
    mintRecipient: string;
    destinationDomain: number;
    estimatedAttestationSeconds: number;
    attested: boolean;
};
export declare type TokenTransferParsed = {
    amount: bigint;
    originAddress: string;
    originChain: number;
    targetAddress: string;
    targetChain: number;
    fromAddress: string | undefined;
    name?: string;
    symbol?: string;
    decimals?: number;
    signedVaaTimestamp?: number;
};
export declare type AdditionalMessageParsed = CCTPTransferParsed | TokenTransferParsed | undefined;
export declare type DeliveryInfo = {
    type: RelayerPayloadId.Delivery;
    sourceChain: ChainName;
    sourceTransactionHash: string;
    sourceDeliverySequenceNumber: number;
    sourceTimestamp: number;
    signingOfVaaTimestamp: number | undefined;
    deliveryInstruction: DeliveryInstruction;
    additionalMessageInformation: AdditionalMessageParsed[];
    targetChainStatus: {
        chain: ChainName;
        events: DeliveryTargetInfo[];
    };
    stringified?: string;
};
export declare type DeliveryArguments = {
    budget: BigNumber;
    deliveryInstruction: DeliveryInstruction;
    deliveryHash: string;
};
export declare function deliver(deliveryVaa: SignedVaa, signer: ethers.Signer, wormholeRPCs: string | string[], environment?: Network, overrides?: DeliveryOverrideArgs): Promise<ContractReceipt>;
export declare function deliveryBudget(delivery: DeliveryInstruction, overrides?: DeliveryOverrideArgs): BigNumber;
export declare function extractDeliveryArguments(vaa: SignedVaa, overrides?: DeliveryOverrideArgs): DeliveryArguments;
export declare function fetchAdditionalVaas(wormholeRPCs: string | string[], additionalVaaKeys: VaaKey[]): Promise<SignedVaa[]>;
